<?php
if ( defined('IS_TEST') ) {
	/** Set up WordPress environment */
    return;
}
$errors = [];

if ($_SERVER['REQUEST_METHOD'] === "POST") {
    if ($_POST['dwd_wc_license_key']) {
        if (!DWD_WC_API_Helper::getInstance()->validateLicense($_POST['dwd_wc_license_key'], $_SERVER['HTTP_REFERER'])) {
            $errors['dwd_wc_license_key'] = "Invalid license code, DWD WooCommerce functionality might be limited.";
        }
    }

    if ($_POST['dwd_wc_userid'] && $_POST['dwd_wc_apikey']) {
        $credentials_status = DWD_WC_API_Helper::getInstance()->validateCredentials(trim($_POST['dwd_wc_userid']), trim($_POST['dwd_wc_apikey']));
        if ($credentials_status === "invalid") {
            $errors['dwd_wc_userid'] = "These credentials are not valid. Please read <a href=\"https://dwd-woocommerce.hjts.nl/plugin-gebruiken/plugin-instellen/\" target=\"_blank\">here</a> to create valid credentials.";
        } else if($credentials_status === "test") {
            $errors['dwd_wc_userid'] = "These test credentials can only be used to set up products. Please read <a href=\"https://dwd-woocommerce.hjts.nl/plugin-gebruiken/plugin-instellen/\" target=\"_blank\">here</a> how to create credentials that can be used for ordering.";
        }
    }
    update_option('dwd-wc-license-key', trim($_POST['dwd_wc_license_key']));
    update_option('dwd-wc-userid', trim($_POST['dwd_wc_userid']));
    update_option('dwd-wc-apikey', trim($_POST['dwd_wc_apikey']));
    update_option('dwd-wc-email', trim($_POST['dwd_wc_email']));
	update_option('dwd-wc-firstname', trim($_POST['dwd_wc_firstname']));
	update_option('dwd-wc-lastname', trim($_POST['dwd_wc_lastname']));
	update_option('dwd-wc-street', trim($_POST['dwd_wc_street']));
	update_option('dwd-wc-housenumber', trim($_POST['dwd_wc_housenumber']));
	update_option('dwd-wc-zipcode', trim($_POST['dwd_wc_zipcode']));
	update_option('dwd-wc-city', trim($_POST['dwd_wc_city']));
	update_option('dwd-wc-country', trim($_POST['dwd_wc_country']));
    update_option('dwd-wc-final-state', trim($_POST['dwd_wc_final_state']));
    update_option('dwd-wc-use-dwd-quantities', trim($_POST['dwd_wc_use_dwd_quantities']));
    if (!$errors) {
	    wp_redirect('admin.php?page=dwd-woocommerce-settings');
    }
}
?>
<div id="poststuff">
	<div id="post-body" class="metabox-holder columns-2">
		<div id="post-body-content">
			<form method="post">
				<table class="form-table">
					<tbody>
                        <tr valign="top">
                            <th class="titledesc" scope="row">License key</th>
                            <td class="forminp forminp-text">
                                <input id="dwd-woocommerce-userid" name="dwd_wc_license_key" type="text" value="<?php echo get_option('dwd-wc-license-key'); ?>" />
                                <?php if (!empty($errors['dwd_wc_license_key'])): ?>
                                    <span style="color: red;"><?php echo $errors['dwd_wc_license_key']; ?></span>
                                <?php endif; ?>
                                <?php if (empty(get_option('dwd-wc-license-key'))): ?>
                                <span>The license is currently free of charge, <a href="https://dwd-woocommerce.hjts.nl/licentiecode-aanvragen/" target="_blank">request one here!</a></span>
                                <?php endif; ?>
                            </td>
                        </tr>
						<tr valign="top">
							<th class="titledesc" scope="row">User-ID</th>
							<td class="forminp forminp-text">
								<input id="dwd-woocommerce-userid" name="dwd_wc_userid" type="text" value="<?php echo get_option('dwd-wc-userid'); ?>" />
                                <?php if (!empty($errors['dwd_wc_userid'])): ?>
                                    <span style="color: red;"><?php echo $errors['dwd_wc_userid']; ?></span>
                                <?php endif; ?>
							</td>
						</tr>
                        <tr valign="top">
                            <th class="titledesc" scope="row">Secret</th>
                            <td class="forminp forminp-text">
                                <input id="dwd-woocommerce-apikey" name="dwd_wc_apikey" type="text" value="<?php echo get_option('dwd-wc-apikey'); ?>" />
                                <?php if (!empty($errors['dwd_wc_apikey'])): ?>
                                    <span style="color: red;"><?php echo $errors['dwd_wc_apikey']; ?></span>
                                <?php endif; ?>
                            </td>
                        </tr>
                        <tr valign="top">
                            <th class="titledesc" scope="row">Billing email</th>
                            <td class="forminp forminp-text">
                                <input id="dwd-woocommerce-email" name="dwd_wc_email" type="text" value="<?php echo get_option('dwd-wc-email'); ?>" />
                            </td>
                        </tr>
                        <tr valign="top">
                            <th class="titledesc" scope="row">First name</th>
                            <td class="forminp forminp-text">
                                <input id="dwd-woocommerce-firstname" name="dwd_wc_firstname" type="text" value="<?php echo get_option('dwd-wc-firstname'); ?>" />
                            </td>
                        </tr>
                        <tr valign="top">
                            <th class="titledesc" scope="row">Last name</th>
                            <td class="forminp forminp-text">
                                <input id="dwd-woocommerce-lastname" name="dwd_wc_lastname" type="text" value="<?php echo get_option('dwd-wc-lastname'); ?>" />
                            </td>
                        </tr>
                        <tr valign="top">
                            <th class="titledesc" scope="row">Street</th>
                            <td class="forminp forminp-text">
                                <input id="dwd-woocommerce-street" name="dwd_wc_street" type="text" value="<?php echo get_option('dwd-wc-street'); ?>" />
                            </td>
                        </tr>
                        <tr valign="top">
                            <th class="titledesc" scope="row">Housenumber</th>
                            <td class="forminp forminp-text">
                                <input id="dwd-woocommerce-housenumber" name="dwd_wc_housenumber" type="text" value="<?php echo get_option('dwd-wc-housenumber'); ?>" />
                            </td>
                        </tr>
                        <tr valign="top">
                            <th class="titledesc" scope="row">Zipcode</th>
                            <td class="forminp forminp-text">
                                <input id="dwd-woocommerce-zipcode" name="dwd_wc_zipcode" type="text" value="<?php echo get_option('dwd-wc-zipcode'); ?>" />
                            </td>
                        </tr>
                        <tr valign="top">
                            <th class="titledesc" scope="row">City</th>
                            <td class="forminp forminp-text">
                                <input id="dwd-woocommerce-city" name="dwd_wc_city" type="text" value="<?php echo get_option('dwd-wc-city'); ?>" />
                            </td>
                        </tr>
                        <tr valign="top">
                            <th class="titledesc" scope="row">Country (e.g. nl, be)</th>
                            <td class="forminp forminp-text">
                                <input id="dwd-woocommerce-country" name="dwd_wc_country" type="text" minlength=2 maxlength=2 value="<?php echo get_option('dwd-wc-country'); ?>" />
                            </td>
                        </tr>
                        <tr valign="top">
                            <th class="titledesc" scope="row">State to switch to when order completed</th>
                            <td class="forminp forminp-text">
                                <?php $final_state = get_option('dwd-wc-final-state', 'wc-dwd-shipped'); ?>
                                <select name="dwd_wc_final_state">
                                    <?php foreach (wc_get_order_statuses() as $name=>$label): ?>
                                        <option <?php if ($name === $final_state): ?>selected="selected"<?php endif; ?> value="<?php echo $name; ?>">
                                            <?php echo $label; ?>
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                            </td>
                        </tr>
                        <tr valign="top">
                            <th class="titledesc" scope="row">Use Drukwerkdeal/Printdeal quantities</th>
                            <td class="forminp forminp-text">
                                <?php $use_dwd_quantities = get_option('dwd-wc-use-dwd-quantities', 1); ?>
                                <input type="hidden" name="dwd_wc_use_dwd_quantities" value="0">
                                <input type = "checkbox" name="dwd_wc_use_dwd_quantities" value="1" <?php if($use_dwd_quantities): ?>checked="checked"<?php endif; ?>>
                            </td>
                        </tr>
					</tbody>
				</table>
                <p class="submit">
                    <button class="button-primary" name="save" type="submit">Save changes</button>
                </p>
			</form>
		</div>
		<br class="clear">
	</div>
</div>
