<?php
add_action( 'dwd_wc_cron_hook', 'dwd_wc_monitor_orders' );
add_filter( 'cron_schedules', 'dwd_wc_one_minute_cron' );
if ( ! wp_next_scheduled( 'dwd_wc_cron_hook' ) ) {
	wp_schedule_event( time(), 'one_minute', 'dwd_wc_cron_hook' );
}
function dwd_wc_one_minute_cron( $schedules ) {
	if (array_key_exists('one_minute', $schedules)) {
		return $schedules;
	}

	$schedules['one_minute'] = array(
		'interval' => 60,
		'display'  => esc_html__( 'Every Minute' ), );

	return $schedules;
}
function dwd_wc_monitor_orders() {
	dwd_wc_process_creating_orders();
	dwd_wc_process_processing_orders();
}

function dwd_wc_process_creating_orders() {
	// handle orders being created:
	foreach (wc_get_orders(['post_status' => 'wc-dwd-creating']) as $order) {
		if (dwd_wc_is_order_ready($order)) {
			dwd_wc_handle_creating_order($order);
		}
	}
}

function dwd_wc_process_processing_orders() {
	$api = DWD_WC_API_Helper::getInstance();
	// handle created orders:
	$state_machine = DWD_WC_State_Machine::getInstance();
	$query_states = $state_machine->get_wc_statuses();
	unset($query_states['shipped']);
	unset($query_states['cancelled']);

	foreach (wc_get_orders(['post_status' => $query_states]) as $order) {
		$order_uuid = $order->get_meta('dwd_order_uuid', true);
		$dwd_order = $api->getOrder($order_uuid);
        if (!is_array($dwd_order) || !array_key_exists('lines', $dwd_order)) {
            continue;
        }
		$wc_state = $state_machine->get_wc_state($dwd_order['lines']);
		$wc_state = apply_filters('dwd-wc-update-state', $wc_state, $order, $dwd_order);

		if (str_replace("wc-", "", $wc_state) !== str_replace("wc-", "", $order->get_status())) {
			$order->set_status($wc_state);
			$order->save();
			// seems to be necessary to
			wp_update_post([
				'ID' => $order->get_id(),
				'post_status' => $wc_state
			]);
		}
	}
}

function dwd_wc_handle_creating_order($order)
{
	$api = DWD_WC_API_Helper::getInstance();
	$state_machine = DWD_WC_State_Machine::getInstance();
	$order_uuid = $order->get_meta('dwd_order_uuid', true);
	$dwd_order = $api->getOrder($order_uuid);

	$order->add_meta_data("dwd_order_number", $dwd_order['number'], true);
	$order->set_status($state_machine->get_wc_state($dwd_order['lines']));
	$order->save();
	return true;
}

function dwd_wc_is_order_ready($order)
{
	$api = DWD_WC_API_Helper::getInstance();
	$order_uuid = $order->get_meta('dwd_order_uuid', true);
	$dwd_order = $api->getOrder($order_uuid);
	if ($dwd_order['error']) {
		return false;
	}
	return true;
}