<?php
/**
 * @package dwd_wc
 * @version 0.0.1
 */

/*
Plugin Name: DWD WooCommerce
Plugin URI: https://dwd-woocommerce.hjts.nl/
Description: Provides integration between WooCommerce and Drukwerkdeal
Author: Henk te Sligte
Version: 1.3.2
License: Private
Author URI: http://hjts.nl/
*/
const DWD_WOOCOMMERCE_PLUGIN_VERSION = "1.3.2";
const DWD_WOOCOMMERCE_PLUGIN_NAME = __FILE__;

add_filter( 'http_request_timeout', function($timeout, $url) { 
	if (stripos($url, "https://api.printdeal.com") !== false) {
		return 60;
	}
	return $timeout;
}, 10, 2);

if (!defined('DWD_WC_WRAPPER_URL')) {
	define('DWD_WC_WRAPPER_URL', 'https://dwd-woocommerce.hjts.nl/api');
}

require_once( __DIR__ . '/API_Helper.php' );
require_once( __DIR__ . '/admin/install.php');
require_once( __DIR__ . '/admin/update.php');
require_once( __DIR__ . '/admin/wc-order/state-machine.php');

register_activation_hook(__FILE__, function() {
    if (get_option('dwd_woocommerce_plugin_version') != DWD_WOOCOMMERCE_PLUGIN_VERSION) {
         dwd_woocommerce_install();
    }
});

add_action( 'init', function () {
    require_once( __DIR__ . '/vendor/autoload.php');
	require_once( __DIR__ . '/admin/wc-tabs/dwd_wc_view_drukwerkdeal_tab.php' );
	require_once( __DIR__ . '/admin/wc-order/status.php' );
	require_once( __DIR__ . '/admin/wc-order/monitor.php' );
	require_once( __DIR__ . '/admin/wc-order/lineitem-file.php' );
	require_once( __DIR__ . '/admin/wc-order/inject-order.php');
	require_once( __DIR__ . '/admin/wc-order/final-state.php' );
    require_once( __DIR__ . '/admin/attribute-validator.php');
    require_once(__DIR__ . '/admin/settings/settings-validator.php');

	require_once( __DIR__ . '/frontend/quantity.php' );

	require_once( 'admin/settings/drukwerkdeal.php' );

	// @todo implement feature to allow writing to db
	if ( ! file_exists( __DIR__ . '/cache' ) ) {
		mkdir( __DIR__ . '/cache' );
	}
} );

add_action( 'admin_enqueue_scripts', function() {
	wp_enqueue_style('dwd-wc-select2', 'https://cdnjs.cloudflare.com/ajax/libs/select2/4.0.3/css/select2.min.css' );
	wp_enqueue_script('dwd-wc-select2', 'https://cdnjs.cloudflare.com/ajax/libs/select2/4.0.3/js/select2.min.js', array('jquery') );
});

add_filter('dwd_wc_api_headers', function($headers) {
	if( ! function_exists('get_plugin_data') ){
        require_once( ABSPATH . 'wp-admin/includes/plugin.php' );
    }
	
	$plugin = get_plugin_data(DWD_WOOCOMMERCE_PLUGIN_NAME, false, false);

	return array_merge(
		$headers,
		[
			'Content-Type' => 'application/json',
			'X-License-Key' => get_option('dwd-wc-license-key'),
			'X-Shop-Id' => sha1(get_option('dwd-wc-userid')),
			'X-Plugin-Name' => $plugin['Name'],
			'X-Plugin-Version' => $plugin['Version'],
		]
	);
});

function dwd_wc_get_product_data(WC_Product $product)
{
	$uuid = $product->get_meta('dwd_product_uuid');
	if (!$uuid) {
		return false;
	}

	$json = $product->get_meta('dwd_product_json');
	if (!$json) {
		return false;
	}

	$product_attributes = json_decode($json, true);
	if (!$product_attributes) {
		return false;
	}

    $file = $product->get_meta("dwd_product_file");

	return ['uuid' => $uuid, 'attributes' => $product_attributes, 'file' => $file];
}

/**
 * @return WC_Product[]
 */
function dwd_wc_get_linked_products()
{
	$linked_products = [];
	foreach (wc_get_products([]) as $product) {
		if ($product instanceof WC_Product_Variable) {
			if (!$product->is_visible()) {
				continue;
			}
			foreach ($product->get_children() as $child_id) {
				$child_product = wc_get_product($child_id);
				if (!$child_product->is_visible()) {
					continue;
				}
				if (dwd_wc_get_product_data($child_product)) {
					$linked_products[] = $child_product;
				}
			}
		}
		elseif ($product instanceof WC_Product_Simple) {
			if (!$product->is_visible()) {
				continue;
			}

			if (dwd_wc_get_product_data($product)) {
				$linked_products[] = $product;
			}
		}
	}
	return $linked_products;
}